Praxis Seizure: Milwaukee Milwaukee, Wisconsin January 19th 2003 10 players Cameron Domer MOTTO: Coming soon to a school board near you. Notes: DO NOT SCARE THE TABLE... if at all convenient. Get out Arika... burn people for fun and profit. Profit is Minion Tap/Voter Cap. Use the Governs to bring out friends for Arika. Relies on Zillah's to outrun Combat Decks to a vampire, who can then be burned with PTO, and fails utterly to weenie combat, fast big combat, Camarilla combat, and any of the same if it's bleed. This deck came into being preNERFing of 5th Tradition. I put it together to see if I could still get big vamp bloat to work. I managed to guess the local metagame to a T on the sect issues required to play the deck. Only one deck I saw was all Camarilla. Changes: Some GtU to Mind Rape, 3 Lucinde 2 Vitel lots more combat D/bleed D depending on metagame. I've added all the Awe's I own, more may be good. Cameron Domer orcaorcinus@hotmail.com Crypt (12 cards, min=40, max=44, avg=10.42) ------------------------------------------- 3x Arika 11 DOM FOR OBF PRE aus cel inner circle Ventrue:2 3x Marcus Vitel 10 DOM FOR OBF OBT PRE prince Ventrue:3 2x Leandro 11 AUS OBF PRE cel dom inner circle Malkavian:2 2x Lucinde, Alastor 10 DOM FOR PRE obf pot tha justicar Ventrue:3 2x Queen Anne 10 DOM FOR PRE aus obf prince Ventrue:2 Library (90 cards) Master (16) 1x Legendary Vampire 10x Minion Tap 5x Zillah's Valley Action (9) 9x Govern the Unaligned Political Action (20) 2x Anarchist Uprising 1x Ancient Influence 1x Ancilla Empowerment 2x Kindred Restructure 14x Protect Thine Own Action Modifier (27) 2x Awe 5x Bewitching Oration 3x Elder Impersonation 7x Forgotten Labyrinth 10x Voter Captivation Action Modifier/Combat (3) 3x Swallowed by the Night Reaction (15) 5x Deflection 5x Obedience 5x Second Tradition: Domain